pype32.directories

Package pype32 :: Module directories |
[hide private]
[frames] | no frames]

# Module directories

source code

PE directory classes.

Classes | [hide private]
| ImageBoundForwarderRefEntry ImageBoundForwarderRefEntry object.
| ImageBoundForwarderRef ImageBoundForwarderRef array object.
| ImageBoundImportDescriptor ImageBoundImportDescriptor object.
| ImageBoundImportDescriptorEntry ImageBoundImportDescriptorEntry object.
| TLSDirectory TLS directory object.
| TLSDirectory64 TLSDirectory64 object.
| ImageBaseRelocationEntry ImageBaseRelocationEntry object.
| ImageBaseRelocation ImageBaseRelocation array.
| ImageDebugDirectory ImageDebugDirectory object.
| ImageDebugDirectories ImageDebugDirectories object.
| ImageImportDescriptorMetaData ImageImportDescriptorMetaData object.
| ImageImportDescriptorEntry ImageImportDescriptorEntry object.
| ImageImportDescriptor ImageImportDescriptor object.
| ImportAddressTableEntry ImportAddressTableEntry object.
| ImportAddressTableEntry64 ImportAddressTableEntry64 object.
| ImportAddressTable Array of ImportAddressTableEntry objects.
| ExportTable Array of ExportTableEntry objects.
| ExportTableEntry ExportTableEntry object.
| ImageExportTable ImageExportTable object.
| NETDirectory NETDirectory object.
| NetDirectory NetDirectory object.
| NetMetaDataHeader NetMetaDataHeader object.
| NetMetaDataStreamEntry NetMetaDataStreamEntry object.
| NetMetaDataStreams NetMetaDataStreams object.
| NetMetaDataTableHeader NetMetaDataTableHeader object.
| NetMetaDataTables NetMetaDataTables object.

Variables | [hide private]
| __revision__ = ``'``$Id$``'``
| __package__ = ``'``pype32``'``